#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fuzzy
version:              0.1.1.0
visibility:           public
id:                   fuzzy-0.1.1.0-KOsifQsTEAF8hLPRUMibhZ
key:                  fuzzy-0.1.1.0-KOsifQsTEAF8hLPRUMibhZ
license:              MIT
maintainer:           joomy@cattheory.com
author:               Joomy Korkut
homepage:             http://github.com/joom/fuzzy
synopsis:             Filters a list based on a fuzzy string search.
category:             Text
abi:                  74cd7584cf5afa609f88d58ec0d52443
exposed:              True
exposed-modules:      Text.Fuzzy
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fuzzy-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fuzzy-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fuzzy-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fuzzy
hs-libraries:         HSfuzzy-0.1.1.0-KOsifQsTEAF8hLPRUMibhZ
depends:
    base-4.18.2.1 monoid-subclasses-1.2.6.1-JRPzbHHktELG1JEiOETw6w

haddock-interfaces:   /usr/share/doc/haskell-fuzzy/html/fuzzy.haddock
haddock-html:         /usr/share/doc/haskell-fuzzy/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

